@@ -1,4 +1,7 @@
 test_that("gggeo_scale() works", {
+  if(!suppressPackageStartupMessages(require(divDyn, quietly = TRUE))) {
+    skip("divDyn not available for gggeo_scale")
+  }
   p <- ggplot(coral_div) +
     geom_line(aes(x = stage_age, y = n)) +
     scale_x_reverse("Age (Ma)") +
@@ -13,6 +16,10 @@ test_that("gggeo_scale() works", {
   expect_true(gtable::is.gtable(gg))
   expect_doppelganger("gggeo_scale() top", gg)
 
+  if(!suppressPackageStartupMessages(require(gsloid, quietly = TRUE))) {
+    skip("gsloid not available for gggeo_scale")
+  }
+  skip_if_offline(host = "macrostrat.org")
   p <- ggplot(lisiecki2005) +
     geom_line(aes(x = d18O, y = Time/1000), orientation = "y") +
     scale_y_reverse("Time (Ma)") +
